"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BrowserTester = void 0;
const expect_1 = require("./expect");
class BrowserTester {
    html = '';
    width;
    height;
    iframe;
    tests = [];
    expects = new expect_1.Expect();
    beforeEachCallbacks = [];
    afterEachCallbacks = [];
    constructor({ html = '', width, height, }) {
        this.html = html;
        if (width) {
            this.width = width;
        }
        if (height) {
            this.height = height;
        }
    }
    setBrowserSize(width, height) {
        if (width) {
            this.iframe.width = `${width}px`;
        }
        if (height) {
            this.iframe.height = `${height}px`;
        }
    }
    beforeEach(callback) {
        this.beforeEachCallbacks.push(callback);
    }
    afterEach(callback) {
        this.afterEachCallbacks.push(callback);
    }
    test(description, callback) {
        this.tests.push({
            description,
            callback,
        });
    }
    expect(value) {
        return this.expects.expect(value);
    }
    clearTests() {
        this.tests = [];
    }
    run() {
        return new Promise((resolve) => {
            const blob = new Blob([this.html], { type: "text/html" });
            const url = URL.createObjectURL(blob);
            const iframe = document.createElement('iframe');
            const body = document.querySelector('body');
            this.iframe = iframe;
            iframe.style.opacity = '0';
            iframe.style.pointerEvents = 'none';
            iframe.src = url;
            if (this.width && this.height) {
                iframe.width = `${this.width}px`;
                iframe.height = `${this.height}px`;
            }
            const iframeCallback = async () => {
                const results = [];
                for (const t of this.tests) {
                    for (const b of this.beforeEachCallbacks) {
                        await b(iframe.contentWindow, iframe.contentDocument);
                    }
                    await t.callback(iframe.contentWindow, iframe.contentDocument);
                    const { description } = t;
                    results.push({
                        description,
                        result: this.expects.isAllPassed()
                    });
                    this.expects.clean();
                    for (const a of this.afterEachCallbacks) {
                        await a(iframe.contentWindow, iframe.contentDocument);
                    }
                }
                iframe.removeEventListener('load', iframeCallback);
                URL.revokeObjectURL(url);
                iframe.remove();
                resolve(results);
            };
            iframe.addEventListener('load', iframeCallback);
            body.appendChild(iframe);
        });
    }
}
exports.BrowserTester = BrowserTester;
